package com.bzd.web.controller.bbfx;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.bbfx.SBbfxKcbbInventoryShortageDetailService;

import java.util.List;

/**
*
* 商品缺货明细表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "bbfx/sbbfxkcbbinventoryshortagedetail")
public class SBbfxKcbbInventoryShortageDetailController extends BaseController {

    // 页面跳转前缀
    private String prefix = "bbfx";

    @Autowired
    private SBbfxKcbbInventoryShortageDetailService sBbfxKcbbInventoryShortageDetailService;

    /**
    * 商品缺货明细表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("bbfx:bb:view")
    @GetMapping("/sBbfxKcbbInventoryShortageDetailAdd")
    public String add() {
        return prefix + "/SBbfxKcbbInventoryShortageDetailAdd";
    }

    /**
    * 商品缺货明细表 新增
    *
    * @return
    */
    @Log(title = "商品缺货明细表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sBbfxKcbbInventoryShortageDetailAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sBbfxKcbbInventoryShortageDetailService.addSBbfxKcbbInventoryShortageDetail(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 商品缺货明细表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("bbfx:bb:view")
    @GetMapping("/sBbfxKcbbInventoryShortageDetailView")
    public String sbbfxkcbbinventoryshortagedetailListView() {
        return prefix + "/SBbfxKcbbInventoryShortageDetailList";
    }

    /**
    * 商品缺货明细表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:sBbfxKcbbInventoryShortageDetailList")
    @PostMapping("/sBbfxKcbbInventoryShortageDetailList")
    @ResponseBody
    public TableDataInfo sbbfxkcbbinventoryshortagedetailList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sBbfxKcbbInventoryShortageDetailService.findSBbfxKcbbInventoryShortageDetailList(pd);
        return getDataTable(pageData);
    }

    /**
    * 商品缺货明细表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:remove")
    @Log(title = "商品缺货明细表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sBbfxKcbbInventoryShortageDetailRemove")
    @ResponseBody
    public AjaxResult sbbfxkcbbinventoryshortagedetailRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sBbfxKcbbInventoryShortageDetailService.SBbfxKcbbInventoryShortageDetailRemove(pd);
        return toAjax(integer);
    }

    /**
    * 商品缺货明细表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:edit")
    @GetMapping("/sBbfxKcbbInventoryShortageDetailEdit/{id}")
    public String sbbfxkcbbinventoryshortagedetailView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sBbfxKcbbInventoryShortageDetailService.findSBbfxKcbbInventoryShortageDetailList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sbbfxkcbbinventoryshortagedetailPageEdit";
        }
        return prefix+ "/sbbfxkcbbinventoryshortagedetailEdit";
    }

    /**
    * 商品缺货明细表保存修改的数据
    */
    @RequiresPermissions("bbfx:bb:edit")
    @Log(title = "商品缺货明细表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sBbfxKcbbInventoryShortageDetailEdit")
    @ResponseBody
    public AjaxResult sbbfxkcbbinventoryshortagedetailEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sBbfxKcbbInventoryShortageDetailService.updateSBbfxKcbbInventoryShortageDetail(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sbbfxkcbbinventoryshortagedetail with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sbbfxkcbbinventoryshortagedetail with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
