package com.bzd.web.controller.bbfx;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.bbfx.SBbfxKcbbJgkcmxService;

import java.util.List;

/**
*
* 机构库存表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "bbfx/sbbfxkcbbjgkcmx")
public class SBbfxKcbbJgkcmxController extends BaseController {

    // 页面跳转前缀
    private String prefix = "bbfx";

    @Autowired
    private SBbfxKcbbJgkcmxService sBbfxKcbbJgkcmxService;

    /**
    * 机构库存表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("bbfx:bb:view")
    @GetMapping("/sBbfxKcbbJgkcmxAdd")
    public String add() {
        return prefix + "/SBbfxKcbbJgkcmxAdd";
    }

    /**
    * 机构库存表 新增
    *
    * @return
    */
    @Log(title = "机构库存表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sBbfxKcbbJgkcmxAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sBbfxKcbbJgkcmxService.addSBbfxKcbbJgkcmx(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 机构库存表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("bbfx:bb:view")
    @GetMapping("/sBbfxKcbbJgkcmxView")
    public String sbbfxkcbbjgkcmxListView() {
        return prefix + "/SBbfxKcbbJgkcmxList";
    }

    /**
    * 机构库存表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:sBbfxKcbbJgkcmxList")
    @PostMapping("/sBbfxKcbbJgkcmxList")
    @ResponseBody
    public TableDataInfo sbbfxkcbbjgkcmxList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sBbfxKcbbJgkcmxService.findSBbfxKcbbJgkcmxList(pd);
        return getDataTable(pageData);
    }

    /**
    * 机构库存表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:remove")
    @Log(title = "机构库存表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sBbfxKcbbJgkcmxRemove")
    @ResponseBody
    public AjaxResult sbbfxkcbbjgkcmxRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sBbfxKcbbJgkcmxService.SBbfxKcbbJgkcmxRemove(pd);
        return toAjax(integer);
    }

    /**
    * 机构库存表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("bbfx:bb:edit")
    @GetMapping("/sBbfxKcbbJgkcmxEdit/{id}")
    public String sbbfxkcbbjgkcmxView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sBbfxKcbbJgkcmxService.findSBbfxKcbbJgkcmxList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sbbfxkcbbjgkcmxPageEdit";
        }
        return prefix+ "/sbbfxkcbbjgkcmxEdit";
    }

    /**
    * 机构库存表保存修改的数据
    */
    @RequiresPermissions("bbfx:bb:edit")
    @Log(title = "机构库存表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sBbfxKcbbJgkcmxEdit")
    @ResponseBody
    public AjaxResult sbbfxkcbbjgkcmxEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sBbfxKcbbJgkcmxService.updateSBbfxKcbbJgkcmx(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sbbfxkcbbjgkcmx with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sbbfxkcbbjgkcmx with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
