package com.bzd.web.controller.cgxs;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.cgxs.SCgxsCfdjPrescriptionRecordService;

import java.util.List;

/**
*
* 处方记录表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "cgxs/scgxscfdjprescriptionrecord")
public class SCgxsCfdjPrescriptionRecordController extends BaseController {

    // 页面跳转前缀
    private String prefix = "cgxs";

    @Autowired
    private SCgxsCfdjPrescriptionRecordService sCgxsCfdjPrescriptionRecordService;

    /**
    * 处方记录表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("cgxs:cg:view")
    @GetMapping("/sCgxsCfdjPrescriptionRecordAdd")
    public String add() {
        return prefix + "/SCgxsCfdjPrescriptionRecordAdd";
    }

    /**
    * 处方记录表 新增
    *
    * @return
    */
    @Log(title = "处方记录表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sCgxsCfdjPrescriptionRecordAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sCgxsCfdjPrescriptionRecordService.addSCgxsCfdjPrescriptionRecord(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 处方记录表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("cgxs:cg:view")
    @GetMapping("/sCgxsCfdjPrescriptionRecordView")
    public String scgxscfdjprescriptionrecordListView() {
        return prefix + "/SCgxsCfdjPrescriptionRecordList";
    }

    /**
    * 处方记录表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:sCgxsCfdjPrescriptionRecordList")
    @PostMapping("/sCgxsCfdjPrescriptionRecordList")
    @ResponseBody
    public TableDataInfo scgxscfdjprescriptionrecordList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sCgxsCfdjPrescriptionRecordService.findSCgxsCfdjPrescriptionRecordList(pd);
        return getDataTable(pageData);
    }

    /**
    * 处方记录表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:remove")
    @Log(title = "处方记录表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sCgxsCfdjPrescriptionRecordRemove")
    @ResponseBody
    public AjaxResult scgxscfdjprescriptionrecordRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sCgxsCfdjPrescriptionRecordService.SCgxsCfdjPrescriptionRecordRemove(pd);
        return toAjax(integer);
    }

    /**
    * 处方记录表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:edit")
    @GetMapping("/sCgxsCfdjPrescriptionRecordEdit/{id}")
    public String scgxscfdjprescriptionrecordView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sCgxsCfdjPrescriptionRecordService.findSCgxsCfdjPrescriptionRecordList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/scgxscfdjprescriptionrecordPageEdit";
        }
        return prefix+ "/scgxscfdjprescriptionrecordEdit";
    }

    /**
    * 处方记录表保存修改的数据
    */
    @RequiresPermissions("cgxs:cg:edit")
    @Log(title = "处方记录表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sCgxsCfdjPrescriptionRecordEdit")
    @ResponseBody
    public AjaxResult scgxscfdjprescriptionrecordEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sCgxsCfdjPrescriptionRecordService.updateSCgxsCfdjPrescriptionRecord(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表scgxscfdjprescriptionrecord with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表scgxscfdjprescriptionrecord with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
