package com.bzd.web.controller.cgxs;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.cgxs.SCgxsTgypTgypdjService;

import java.util.List;

/**
*
* 特管药品登记表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "cgxs/scgxstgyptgypdj")
public class SCgxsTgypTgypdjController extends BaseController {

    // 页面跳转前缀
    private String prefix = "cgxs";

    @Autowired
    private SCgxsTgypTgypdjService sCgxsTgypTgypdjService;

    /**
    * 特管药品登记表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("cgxs:cg:view")
    @GetMapping("/sCgxsTgypTgypdjAdd")
    public String add() {
        return prefix + "/SCgxsTgypTgypdjAdd";
    }

    /**
    * 特管药品登记表 新增
    *
    * @return
    */
    @Log(title = "特管药品登记表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sCgxsTgypTgypdjAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sCgxsTgypTgypdjService.addSCgxsTgypTgypdj(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 特管药品登记表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("cgxs:cg:view")
    @GetMapping("/sCgxsTgypTgypdjView")
    public String scgxstgyptgypdjListView() {
        return prefix + "/SCgxsTgypTgypdjList";
    }

    /**
    * 特管药品登记表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:sCgxsTgypTgypdjList")
    @PostMapping("/sCgxsTgypTgypdjList")
    @ResponseBody
    public TableDataInfo scgxstgyptgypdjList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sCgxsTgypTgypdjService.findSCgxsTgypTgypdjList(pd);
        return getDataTable(pageData);
    }

    /**
    * 特管药品登记表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:remove")
    @Log(title = "特管药品登记表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sCgxsTgypTgypdjRemove")
    @ResponseBody
    public AjaxResult scgxstgyptgypdjRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sCgxsTgypTgypdjService.SCgxsTgypTgypdjRemove(pd);
        return toAjax(integer);
    }

    /**
    * 特管药品登记表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("cgxs:cg:edit")
    @GetMapping("/sCgxsTgypTgypdjEdit/{id}")
    public String scgxstgyptgypdjView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sCgxsTgypTgypdjService.findSCgxsTgypTgypdjList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/scgxstgyptgypdjPageEdit";
        }
        return prefix+ "/scgxstgyptgypdjEdit";
    }

    /**
    * 特管药品登记表保存修改的数据
    */
    @RequiresPermissions("cgxs:cg:edit")
    @Log(title = "特管药品登记表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sCgxsTgypTgypdjEdit")
    @ResponseBody
    public AjaxResult scgxstgyptgypdjEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sCgxsTgypTgypdjService.updateSCgxsTgypTgypdj(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表scgxstgyptgypdj with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表scgxstgyptgypdj with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
