package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpSjdcQualityInspectionTaskService;

import java.util.List;

/**
*
* 质检任务表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpsjdcqualityinspectiontask")
public class SDtpSjdcQualityInspectionTaskController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpSjdcQualityInspectionTaskService sDtpSjdcQualityInspectionTaskService;

    /**
    * 质检任务表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpSjdcQualityInspectionTaskAdd")
    public String add() {
        return prefix + "/SDtpSjdcQualityInspectionTaskAdd";
    }

    /**
    * 质检任务表 新增
    *
    * @return
    */
    @Log(title = "质检任务表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpSjdcQualityInspectionTaskAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpSjdcQualityInspectionTaskService.addSDtpSjdcQualityInspectionTask(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 质检任务表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpSjdcQualityInspectionTaskView")
    public String sdtpsjdcqualityinspectiontaskListView() {
        return prefix + "/SDtpSjdcQualityInspectionTaskList";
    }

    /**
    * 质检任务表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:sDtpSjdcQualityInspectionTaskList")
    @PostMapping("/sDtpSjdcQualityInspectionTaskList")
    @ResponseBody
    public TableDataInfo sdtpsjdcqualityinspectiontaskList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpSjdcQualityInspectionTaskService.findSDtpSjdcQualityInspectionTaskList(pd);
        return getDataTable(pageData);
    }

    /**
    * 质检任务表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "质检任务表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpSjdcQualityInspectionTaskRemove")
    @ResponseBody
    public AjaxResult sdtpsjdcqualityinspectiontaskRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpSjdcQualityInspectionTaskService.SDtpSjdcQualityInspectionTaskRemove(pd);
        return toAjax(integer);
    }

    /**
    * 质检任务表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpSjdcQualityInspectionTaskEdit/{id}")
    public String sdtpsjdcqualityinspectiontaskView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpSjdcQualityInspectionTaskService.findSDtpSjdcQualityInspectionTaskList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sdtpsjdcqualityinspectiontaskPageEdit";
        }
        return prefix+ "/sdtpsjdcqualityinspectiontaskEdit";
    }

    /**
    * 质检任务表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "质检任务表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpSjdcQualityInspectionTaskEdit")
    @ResponseBody
    public AjaxResult sdtpsjdcqualityinspectiontaskEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpSjdcQualityInspectionTaskService.updateSDtpSjdcQualityInspectionTask(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpsjdcqualityinspectiontask with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpsjdcqualityinspectiontask with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
