package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpYypzCallWordService;

import java.util.List;

/**
*
* 提示词管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpyypzcallword")
public class SDtpYypzCallWordController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpYypzCallWordService sDtpYypzCallWordService;

    /**
    * 提示词管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpYypzCallWordAdd")
    public String add() {
        return prefix + "/SDtpYypzCallWordAdd";
    }

    /**
    * 提示词管理表 新增
    *
    * @return
    */
    @Log(title = "提示词管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpYypzCallWordAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpYypzCallWordService.addSDtpYypzCallWord(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 提示词管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpYypzCallWordView")
    public String sdtpyypzcallwordListView() {
        return prefix + "/SDtpYypzCallWordList";
    }

    /**
    * 提示词管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:sDtpYypzCallWordList")
    @PostMapping("/sDtpYypzCallWordList")
    @ResponseBody
    public TableDataInfo sdtpyypzcallwordList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpYypzCallWordService.findSDtpYypzCallWordList(pd);
        return getDataTable(pageData);
    }

    /**
    * 提示词管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "提示词管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpYypzCallWordRemove")
    @ResponseBody
    public AjaxResult sdtpyypzcallwordRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpYypzCallWordService.SDtpYypzCallWordRemove(pd);
        return toAjax(integer);
    }

    /**
    * 提示词管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpYypzCallWordEdit/{id}")
    public String sdtpyypzcallwordView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpYypzCallWordService.findSDtpYypzCallWordList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sdtpyypzcallwordPageEdit";
        }
        return prefix+ "/sdtpyypzcallwordEdit";
    }

    /**
    * 提示词管理表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "提示词管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpYypzCallWordEdit")
    @ResponseBody
    public AjaxResult sdtpyypzcallwordEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpYypzCallWordService.updateSDtpYypzCallWord(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpyypzcallword with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpyypzcallword with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
