package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpYypzFaqManagementService;

import java.util.List;

/**
*
* 常用问答管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpyypzfaqmanagement")
public class SDtpYypzFaqManagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpYypzFaqManagementService sDtpYypzFaqManagementService;

    /**
    * 常用问答管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpYypzFaqManagementAdd")
    public String add() {
        return prefix + "/SDtpYypzFaqManagementAdd";
    }

    /**
    * 常用问答管理表 新增
    *
    * @return
    */
    @Log(title = "常用问答管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpYypzFaqManagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpYypzFaqManagementService.addSDtpYypzFaqManagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 常用问答管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpYypzFaqManagementView")
    public String sdtpyypzfaqmanagementListView() {
        return prefix + "/SDtpYypzFaqManagementList";
    }

    /**
    * 常用问答管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:sDtpYypzFaqManagementList")
    @PostMapping("/sDtpYypzFaqManagementList")
    @ResponseBody
    public TableDataInfo sdtpyypzfaqmanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpYypzFaqManagementService.findSDtpYypzFaqManagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 常用问答管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "常用问答管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpYypzFaqManagementRemove")
    @ResponseBody
    public AjaxResult sdtpyypzfaqmanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpYypzFaqManagementService.SDtpYypzFaqManagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 常用问答管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpYypzFaqManagementEdit/{id}")
    public String sdtpyypzfaqmanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpYypzFaqManagementService.findSDtpYypzFaqManagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sdtpyypzfaqmanagementPageEdit";
        }
        return prefix+ "/sdtpyypzfaqmanagementEdit";
    }

    /**
    * 常用问答管理表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "常用问答管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpYypzFaqManagementEdit")
    @ResponseBody
    public AjaxResult sdtpyypzfaqmanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpYypzFaqManagementService.updateSDtpYypzFaqManagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpyypzfaqmanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpyypzfaqmanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
