package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpZskcxFollowUpGuidanceService;

import java.util.List;

/**
*
* 随访指导管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpzskcxfollowupguidance")
public class SDtpZskcxFollowUpGuidanceController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpZskcxFollowUpGuidanceService sDtpZskcxFollowUpGuidanceService;

    /**
    * 随访指导管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxFollowUpGuidanceAdd")
    public String add() {
        return prefix + "/SDtpZskcxFollowUpGuidanceAdd";
    }

    /**
    * 随访指导管理表 新增
    *
    * @return
    */
    @Log(title = "随访指导管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpZskcxFollowUpGuidanceAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpZskcxFollowUpGuidanceService.addSDtpZskcxFollowUpGuidance(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 随访指导管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxFollowUpGuidanceView")
    public String sdtpzskcxfollowupguidanceListView() {
        return prefix + "/SDtpZskcxFollowUpGuidanceList";
    }

    /**
    * 随访指导管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:sDtpZskcxFollowUpGuidanceList")
    @PostMapping("/sDtpZskcxFollowUpGuidanceList")
    @ResponseBody
    public TableDataInfo sdtpzskcxfollowupguidanceList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpZskcxFollowUpGuidanceService.findSDtpZskcxFollowUpGuidanceList(pd);
        return getDataTable(pageData);
    }

    /**
    * 随访指导管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "随访指导管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpZskcxFollowUpGuidanceRemove")
    @ResponseBody
    public AjaxResult sdtpzskcxfollowupguidanceRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpZskcxFollowUpGuidanceService.SDtpZskcxFollowUpGuidanceRemove(pd);
        return toAjax(integer);
    }

    /**
    * 随访指导管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpZskcxFollowUpGuidanceEdit/{id}")
    public String sdtpzskcxfollowupguidanceView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpZskcxFollowUpGuidanceService.findSDtpZskcxFollowUpGuidanceList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sdtpzskcxfollowupguidancePageEdit";
        }
        return prefix+ "/sdtpzskcxfollowupguidanceEdit";
    }

    /**
    * 随访指导管理表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "随访指导管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpZskcxFollowUpGuidanceEdit")
    @ResponseBody
    public AjaxResult sdtpzskcxfollowupguidanceEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpZskcxFollowUpGuidanceService.updateSDtpZskcxFollowUpGuidance(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpzskcxfollowupguidance with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpzskcxfollowupguidance with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
