package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpZskcxPharmacovigilanceService;

import java.util.List;

/**
*
* 药学警戒表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpzskcxpharmacovigilance")
public class SDtpZskcxPharmacovigilanceController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpZskcxPharmacovigilanceService sDtpZskcxPharmacovigilanceService;

    /**
    * 药学警戒表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxPharmacovigilanceAdd")
    public String add() {
        return prefix + "/SDtpZskcxPharmacovigilanceAdd";
    }

    /**
    * 药学警戒表 新增
    *
    * @return
    */
    @Log(title = "药学警戒表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpZskcxPharmacovigilanceAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpZskcxPharmacovigilanceService.addSDtpZskcxPharmacovigilance(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 药学警戒表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxPharmacovigilanceView")
    public String sdtpzskcxpharmacovigilanceListView() {
        return prefix + "/SDtpZskcxPharmacovigilanceList";
    }

    /**
    * 药学警戒表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:sDtpZskcxPharmacovigilanceList")
    @PostMapping("/sDtpZskcxPharmacovigilanceList")
    @ResponseBody
    public TableDataInfo sdtpzskcxpharmacovigilanceList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpZskcxPharmacovigilanceService.findSDtpZskcxPharmacovigilanceList(pd);
        return getDataTable(pageData);
    }

    /**
    * 药学警戒表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "药学警戒表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpZskcxPharmacovigilanceRemove")
    @ResponseBody
    public AjaxResult sdtpzskcxpharmacovigilanceRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpZskcxPharmacovigilanceService.SDtpZskcxPharmacovigilanceRemove(pd);
        return toAjax(integer);
    }

    /**
    * 药学警戒表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpZskcxPharmacovigilanceEdit/{id}")
    public String sdtpzskcxpharmacovigilanceView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpZskcxPharmacovigilanceService.findSDtpZskcxPharmacovigilanceList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sdtpzskcxpharmacovigilancePageEdit";
        }
        return prefix+ "/sdtpzskcxpharmacovigilanceEdit";
    }

    /**
    * 药学警戒表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "药学警戒表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpZskcxPharmacovigilanceEdit")
    @ResponseBody
    public AjaxResult sdtpzskcxpharmacovigilanceEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpZskcxPharmacovigilanceService.updateSDtpZskcxPharmacovigilance(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpzskcxpharmacovigilance with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpzskcxpharmacovigilance with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
