package com.bzd.web.controller.fwgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.fwgl.SFwglServerinfoService;

import java.util.List;

/**
*
* 服务包列表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "fwgl/sfwglserverinfo")
public class SFwglServerinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "fwgl";

    @Autowired
    private SFwglServerinfoService sFwglServerinfoService;

    /**
    * 服务包列表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("fwgl:fw:view")
    @GetMapping("/sFwglServerinfoAdd")
    public String add() {
        return prefix + "/SFwglServerinfoAdd";
    }

    /**
    * 服务包列表 新增
    *
    * @return
    */
    @Log(title = "服务包列表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sFwglServerinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sFwglServerinfoService.addSFwglServerinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 服务包列表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("fwgl:fw:view")
    @GetMapping("/sFwglServerinfoView")
    public String sfwglserverinfoListView() {
        return prefix + "/SFwglServerinfoList";
    }

    /**
    * 服务包列表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:sFwglServerinfoList")
    @PostMapping("/sFwglServerinfoList")
    @ResponseBody
    public TableDataInfo sfwglserverinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sFwglServerinfoService.findSFwglServerinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 服务包列表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:remove")
    @Log(title = "服务包列表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sFwglServerinfoRemove")
    @ResponseBody
    public AjaxResult sfwglserverinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sFwglServerinfoService.SFwglServerinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 服务包列表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:edit")
    @GetMapping("/sFwglServerinfoEdit/{id}")
    public String sfwglserverinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sFwglServerinfoService.findSFwglServerinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sfwglserverinfoPageEdit";
        }
        return prefix+ "/sfwglserverinfoEdit";
    }

    /**
    * 服务包列表保存修改的数据
    */
    @RequiresPermissions("fwgl:fw:edit")
    @Log(title = "服务包列表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sFwglServerinfoEdit")
    @ResponseBody
    public AjaxResult sfwglserverinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sFwglServerinfoService.updateSFwglServerinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sfwglserverinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sfwglserverinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
