package com.bzd.web.controller.fwgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.fwgl.SFwglServerorderinfoService;

import java.util.List;

/**
*
* 服务包订单 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "fwgl/sfwglserverorderinfo")
public class SFwglServerorderinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "fwgl";

    @Autowired
    private SFwglServerorderinfoService sFwglServerorderinfoService;

    /**
    * 服务包订单 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("fwgl:fw:view")
    @GetMapping("/sFwglServerorderinfoAdd")
    public String add() {
        return prefix + "/SFwglServerorderinfoAdd";
    }

    /**
    * 服务包订单 新增
    *
    * @return
    */
    @Log(title = "服务包订单新增", businessType = BusinessType.INSERT)
    @PostMapping("/sFwglServerorderinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sFwglServerorderinfoService.addSFwglServerorderinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 服务包订单 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("fwgl:fw:view")
    @GetMapping("/sFwglServerorderinfoView")
    public String sfwglserverorderinfoListView() {
        return prefix + "/SFwglServerorderinfoList";
    }

    /**
    * 服务包订单 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:sFwglServerorderinfoList")
    @PostMapping("/sFwglServerorderinfoList")
    @ResponseBody
    public TableDataInfo sfwglserverorderinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sFwglServerorderinfoService.findSFwglServerorderinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 服务包订单 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:remove")
    @Log(title = "服务包订单删除", businessType = BusinessType.DELETE)
    @PostMapping("/sFwglServerorderinfoRemove")
    @ResponseBody
    public AjaxResult sfwglserverorderinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sFwglServerorderinfoService.SFwglServerorderinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 服务包订单 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("fwgl:fw:edit")
    @GetMapping("/sFwglServerorderinfoEdit/{id}")
    public String sfwglserverorderinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sFwglServerorderinfoService.findSFwglServerorderinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sfwglserverorderinfoPageEdit";
        }
        return prefix+ "/sfwglserverorderinfoEdit";
    }

    /**
    * 服务包订单保存修改的数据
    */
    @RequiresPermissions("fwgl:fw:edit")
    @Log(title = "服务包订单修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sFwglServerorderinfoEdit")
    @ResponseBody
    public AjaxResult sfwglserverorderinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sFwglServerorderinfoService.updateSFwglServerorderinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sfwglserverorderinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sfwglserverorderinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
