package com.bzd.web.controller.gjgzt;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.gjgzt.SGjgztHealthplaninfoService;

import java.util.List;

/**
*
* 管家工作台 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "gjgzt/sgjgzthealthplaninfo")
public class SGjgztHealthplaninfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "gjgzt";

    @Autowired
    private SGjgztHealthplaninfoService sGjgztHealthplaninfoService;

    /**
    * 管家工作台 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("gjgzt:gj:view")
    @GetMapping("/sGjgztHealthplaninfoAdd")
    public String add() {
        return prefix + "/SGjgztHealthplaninfoAdd";
    }

    /**
    * 管家工作台 新增
    *
    * @return
    */
    @Log(title = "管家工作台新增", businessType = BusinessType.INSERT)
    @PostMapping("/sGjgztHealthplaninfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sGjgztHealthplaninfoService.addSGjgztHealthplaninfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 管家工作台 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("gjgzt:gj:view")
    @GetMapping("/sGjgztHealthplaninfoView")
    public String sgjgzthealthplaninfoListView() {
        return prefix + "/SGjgztHealthplaninfoList";
    }

    /**
    * 管家工作台 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gjgzt:gj:sGjgztHealthplaninfoList")
    @PostMapping("/sGjgztHealthplaninfoList")
    @ResponseBody
    public TableDataInfo sgjgzthealthplaninfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sGjgztHealthplaninfoService.findSGjgztHealthplaninfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 管家工作台 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gjgzt:gj:remove")
    @Log(title = "管家工作台删除", businessType = BusinessType.DELETE)
    @PostMapping("/sGjgztHealthplaninfoRemove")
    @ResponseBody
    public AjaxResult sgjgzthealthplaninfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sGjgztHealthplaninfoService.SGjgztHealthplaninfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 管家工作台 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gjgzt:gj:edit")
    @GetMapping("/sGjgztHealthplaninfoEdit/{id}")
    public String sgjgzthealthplaninfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sGjgztHealthplaninfoService.findSGjgztHealthplaninfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sgjgzthealthplaninfoPageEdit";
        }
        return prefix+ "/sgjgzthealthplaninfoEdit";
    }

    /**
    * 管家工作台保存修改的数据
    */
    @RequiresPermissions("gjgzt:gj:edit")
    @Log(title = "管家工作台修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sGjgztHealthplaninfoEdit")
    @ResponseBody
    public AjaxResult sgjgzthealthplaninfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sGjgztHealthplaninfoService.updateSGjgztHealthplaninfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sgjgzthealthplaninfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sgjgzthealthplaninfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
