package com.bzd.web.controller.gkdggl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.gkdggl.SGkdgglCustomerOrderAuditService;

import java.util.List;

/**
*
* 顾客订购审核表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "gkdggl/sgkdgglcustomerorderaudit")
public class SGkdgglCustomerOrderAuditController extends BaseController {

    // 页面跳转前缀
    private String prefix = "gkdggl";

    @Autowired
    private SGkdgglCustomerOrderAuditService sGkdgglCustomerOrderAuditService;

    /**
    * 顾客订购审核表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("gkdggl:gk:view")
    @GetMapping("/sGkdgglCustomerOrderAuditAdd")
    public String add() {
        return prefix + "/SGkdgglCustomerOrderAuditAdd";
    }

    /**
    * 顾客订购审核表 新增
    *
    * @return
    */
    @Log(title = "顾客订购审核表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sGkdgglCustomerOrderAuditAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sGkdgglCustomerOrderAuditService.addSGkdgglCustomerOrderAudit(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 顾客订购审核表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("gkdggl:gk:view")
    @GetMapping("/sGkdgglCustomerOrderAuditView")
    public String sgkdgglcustomerorderauditListView() {
        return prefix + "/SGkdgglCustomerOrderAuditList";
    }

    /**
    * 顾客订购审核表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gkdggl:gk:sGkdgglCustomerOrderAuditList")
    @PostMapping("/sGkdgglCustomerOrderAuditList")
    @ResponseBody
    public TableDataInfo sgkdgglcustomerorderauditList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sGkdgglCustomerOrderAuditService.findSGkdgglCustomerOrderAuditList(pd);
        return getDataTable(pageData);
    }

    /**
    * 顾客订购审核表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gkdggl:gk:remove")
    @Log(title = "顾客订购审核表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sGkdgglCustomerOrderAuditRemove")
    @ResponseBody
    public AjaxResult sgkdgglcustomerorderauditRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sGkdgglCustomerOrderAuditService.SGkdgglCustomerOrderAuditRemove(pd);
        return toAjax(integer);
    }

    /**
    * 顾客订购审核表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("gkdggl:gk:edit")
    @GetMapping("/sGkdgglCustomerOrderAuditEdit/{id}")
    public String sgkdgglcustomerorderauditView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sGkdgglCustomerOrderAuditService.findSGkdgglCustomerOrderAuditList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sgkdgglcustomerorderauditPageEdit";
        }
        return prefix+ "/sgkdgglcustomerorderauditEdit";
    }

    /**
    * 顾客订购审核表保存修改的数据
    */
    @RequiresPermissions("gkdggl:gk:edit")
    @Log(title = "顾客订购审核表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sGkdgglCustomerOrderAuditEdit")
    @ResponseBody
    public AjaxResult sgkdgglcustomerorderauditEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sGkdgglCustomerOrderAuditService.updateSGkdgglCustomerOrderAudit(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sgkdgglcustomerorderaudit with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sgkdgglcustomerorderaudit with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
