package com.bzd.web.controller.hygl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.hygl.SHyglEquitiesService;

import java.util.List;

/**
*
* 权益管理 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "hygl/shyglequities")
public class SHyglEquitiesController extends BaseController {

    // 页面跳转前缀
    private String prefix = "hygl/";

    @Autowired
    private SHyglEquitiesService sHyglEquitiesService;

    /**
    * 权益管理 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:hygl:view")
    @GetMapping("/sHyglEquitiesAdd")
    public String add() {
        return prefix + "/SHyglEquitiesAdd";
    }

    /**
    * 权益管理 新增
    *
    * @return
    */
    @Log(title = "权益管理新增", businessType = BusinessType.INSERT)
    @PostMapping("/sHyglEquitiesAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sHyglEquitiesService.addSHyglEquities(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 权益管理 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:hygl:view")
    @GetMapping("/sHyglEquitiesView")
    public String shyglequitiesListView() {
        return prefix + "/SHyglEquitiesList";
    }

    /**
    * 权益管理 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:sHyglEquitiesList")
    @PostMapping("/sHyglEquitiesList")
    @ResponseBody
    public TableDataInfo shyglequitiesList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sHyglEquitiesService.findSHyglEquitiesList(pd);
        return getDataTable(pageData);
    }

    /**
    * 权益管理 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:remove")
    @Log(title = "权益管理删除", businessType = BusinessType.DELETE)
    @PostMapping("/sHyglEquitiesRemove")
    @ResponseBody
    public AjaxResult shyglequitiesRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sHyglEquitiesService.SHyglEquitiesRemove(pd);
        return toAjax(integer);
    }

    /**
    * 权益管理 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:edit")
    @GetMapping("/sHyglEquitiesEdit/{id}")
    public String shyglequitiesView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sHyglEquitiesService.findSHyglEquitiesList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/shyglequitiesPageEdit";
        }
        return prefix+ "/shyglequitiesEdit";
    }

    /**
    * 权益管理保存修改的数据
    */
    @RequiresPermissions("hygl:hygl:edit")
    @Log(title = "权益管理修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sHyglEquitiesEdit")
    @ResponseBody
    public AjaxResult shyglequitiesEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sHyglEquitiesService.updateSHyglEquities(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表shyglequities with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表shyglequities with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
