package com.bzd.web.controller.hygl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.hygl.SHyglMembertagService;

import java.util.List;

/**
*
* 会员标签表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "hygl/shyglmembertag")
public class SHyglMembertagController extends BaseController {

    // 页面跳转前缀
    private String prefix = "hygl/";

    @Autowired
    private SHyglMembertagService sHyglMembertagService;

    /**
    * 会员标签表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:hygl:view")
    @GetMapping("/sHyglMembertagAdd")
    public String add() {
        return prefix + "/SHyglMembertagAdd";
    }

    /**
    * 会员标签表 新增
    *
    * @return
    */
    @Log(title = "会员标签表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sHyglMembertagAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sHyglMembertagService.addSHyglMembertag(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 会员标签表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:hygl:view")
    @GetMapping("/sHyglMembertagView")
    public String shyglmembertagListView() {
        return prefix + "/SHyglMembertagList";
    }

    /**
    * 会员标签表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:sHyglMembertagList")
    @PostMapping("/sHyglMembertagList")
    @ResponseBody
    public TableDataInfo shyglmembertagList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sHyglMembertagService.findSHyglMembertagList(pd);
        return getDataTable(pageData);
    }

    /**
    * 会员标签表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:remove")
    @Log(title = "会员标签表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sHyglMembertagRemove")
    @ResponseBody
    public AjaxResult shyglmembertagRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sHyglMembertagService.SHyglMembertagRemove(pd);
        return toAjax(integer);
    }

    /**
    * 会员标签表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:hygl:edit")
    @GetMapping("/sHyglMembertagEdit/{id}")
    public String shyglmembertagView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sHyglMembertagService.findSHyglMembertagList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/shyglmembertagPageEdit";
        }
        return prefix+ "/shyglmembertagEdit";
    }

    /**
    * 会员标签表保存修改的数据
    */
    @RequiresPermissions("hygl:hygl:edit")
    @Log(title = "会员标签表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sHyglMembertagEdit")
    @ResponseBody
    public AjaxResult shyglmembertagEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sHyglMembertagService.updateSHyglMembertag(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表shyglmembertag with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表shyglmembertag with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
