package com.bzd.web.controller.hygl.jf;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.hygl.jf.SHyglJfglPointAdjustmentService;

import java.util.List;

/**
*
* 积分调整表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "hygl/shygljfglpointadjustment")
public class SHyglJfglPointAdjustmentController extends BaseController {

    // 页面跳转前缀
    private String prefix = "hygl/jf";

    @Autowired
    private SHyglJfglPointAdjustmentService sHyglJfglPointAdjustmentService;

    /**
    * 积分调整表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:jf:view")
    @GetMapping("/sHyglJfglPointAdjustmentAdd")
    public String add() {
        return prefix + "/SHyglJfglPointAdjustmentAdd";
    }

    /**
    * 积分调整表 新增
    *
    * @return
    */
    @Log(title = "积分调整表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sHyglJfglPointAdjustmentAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sHyglJfglPointAdjustmentService.addSHyglJfglPointAdjustment(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 积分调整表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:jf:view")
    @GetMapping("/sHyglJfglPointAdjustmentView")
    public String shygljfglpointadjustmentListView() {
        return prefix + "/SHyglJfglPointAdjustmentList";
    }

    /**
    * 积分调整表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:jf:sHyglJfglPointAdjustmentList")
    @PostMapping("/sHyglJfglPointAdjustmentList")
    @ResponseBody
    public TableDataInfo shygljfglpointadjustmentList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sHyglJfglPointAdjustmentService.findSHyglJfglPointAdjustmentList(pd);
        return getDataTable(pageData);
    }

    /**
    * 积分调整表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:jf:remove")
    @Log(title = "积分调整表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sHyglJfglPointAdjustmentRemove")
    @ResponseBody
    public AjaxResult shygljfglpointadjustmentRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sHyglJfglPointAdjustmentService.SHyglJfglPointAdjustmentRemove(pd);
        return toAjax(integer);
    }

    /**
    * 积分调整表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:jf:edit")
    @GetMapping("/sHyglJfglPointAdjustmentEdit/{id}")
    public String shygljfglpointadjustmentView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sHyglJfglPointAdjustmentService.findSHyglJfglPointAdjustmentList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/shygljfglpointadjustmentPageEdit";
        }
        return prefix+ "/shygljfglpointadjustmentEdit";
    }

    /**
    * 积分调整表保存修改的数据
    */
    @RequiresPermissions("hygl:jf:edit")
    @Log(title = "积分调整表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sHyglJfglPointAdjustmentEdit")
    @ResponseBody
    public AjaxResult shygljfglpointadjustmentEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sHyglJfglPointAdjustmentService.updateSHyglJfglPointAdjustment(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表shygljfglpointadjustment with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表shygljfglpointadjustment with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
