package com.bzd.web.controller.hygl.yx;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.hygl.yx.SHyglHyyxPeoplemanagementService;

import java.util.List;

/**
*
* 人群管理表（精准营销） 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "hygl/shyglhyyxpeoplemanagement")
public class SHyglHyyxPeoplemanagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "hygl/yx";

    @Autowired
    private SHyglHyyxPeoplemanagementService sHyglHyyxPeoplemanagementService;

    /**
    * 人群管理表（精准营销） 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:yx:view")
    @GetMapping("/sHyglHyyxPeoplemanagementAdd")
    public String add() {
        return prefix + "/SHyglHyyxPeoplemanagementAdd";
    }

    /**
    * 人群管理表（精准营销） 新增
    *
    * @return
    */
    @Log(title = "人群管理表（精准营销）新增", businessType = BusinessType.INSERT)
    @PostMapping("/sHyglHyyxPeoplemanagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sHyglHyyxPeoplemanagementService.addSHyglHyyxPeoplemanagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 人群管理表（精准营销） 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("hygl:yx:view")
    @GetMapping("/sHyglHyyxPeoplemanagementView")
    public String shyglhyyxpeoplemanagementListView() {
        return prefix + "/SHyglHyyxPeoplemanagementList";
    }

    /**
    * 人群管理表（精准营销） 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:yx:sHyglHyyxPeoplemanagementList")
    @PostMapping("/sHyglHyyxPeoplemanagementList")
    @ResponseBody
    public TableDataInfo shyglhyyxpeoplemanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sHyglHyyxPeoplemanagementService.findSHyglHyyxPeoplemanagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 人群管理表（精准营销） 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:yx:remove")
    @Log(title = "人群管理表（精准营销）删除", businessType = BusinessType.DELETE)
    @PostMapping("/sHyglHyyxPeoplemanagementRemove")
    @ResponseBody
    public AjaxResult shyglhyyxpeoplemanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sHyglHyyxPeoplemanagementService.SHyglHyyxPeoplemanagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 人群管理表（精准营销） 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("hygl:yx:edit")
    @GetMapping("/sHyglHyyxPeoplemanagementEdit/{id}")
    public String shyglhyyxpeoplemanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sHyglHyyxPeoplemanagementService.findSHyglHyyxPeoplemanagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/shyglhyyxpeoplemanagementPageEdit";
        }
        return prefix+ "/shyglhyyxpeoplemanagementEdit";
    }

    /**
    * 人群管理表（精准营销）保存修改的数据
    */
    @RequiresPermissions("hygl:yx:edit")
    @Log(title = "人群管理表（精准营销）修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sHyglHyyxPeoplemanagementEdit")
    @ResponseBody
    public AjaxResult shyglhyyxpeoplemanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sHyglHyyxPeoplemanagementService.updateSHyglHyyxPeoplemanagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表shyglhyyxpeoplemanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表shyglhyyxpeoplemanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
