package com.bzd.web.controller.jggl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.jggl.SJgglPriceadjustmentsheetService;

import java.util.List;

/**
*
* 价格调整通知 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "jggl/sjgglpriceadjustmentsheet")
public class SJgglPriceadjustmentsheetController extends BaseController {

    // 页面跳转前缀
    private String prefix = "jggl";

    @Autowired
    private SJgglPriceadjustmentsheetService sJgglPriceadjustmentsheetService;

    /**
    * 价格调整通知 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("jggl:jg:view")
    @GetMapping("/sJgglPriceadjustmentsheetAdd")
    public String add() {
        return prefix + "/SJgglPriceadjustmentsheetAdd";
    }

    /**
    * 价格调整通知 新增
    *
    * @return
    */
    @Log(title = "价格调整通知新增", businessType = BusinessType.INSERT)
    @PostMapping("/sJgglPriceadjustmentsheetAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sJgglPriceadjustmentsheetService.addSJgglPriceadjustmentsheet(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 价格调整通知 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("jggl:jg:view")
    @GetMapping("/sJgglPriceadjustmentsheetView")
    public String sjgglpriceadjustmentsheetListView() {
        return prefix + "/SJgglPriceadjustmentsheetList";
    }

    /**
    * 价格调整通知 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jggl:jg:sJgglPriceadjustmentsheetList")
    @PostMapping("/sJgglPriceadjustmentsheetList")
    @ResponseBody
    public TableDataInfo sjgglpriceadjustmentsheetList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sJgglPriceadjustmentsheetService.findSJgglPriceadjustmentsheetList(pd);
        return getDataTable(pageData);
    }

    /**
    * 价格调整通知 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jggl:jg:remove")
    @Log(title = "价格调整通知删除", businessType = BusinessType.DELETE)
    @PostMapping("/sJgglPriceadjustmentsheetRemove")
    @ResponseBody
    public AjaxResult sjgglpriceadjustmentsheetRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sJgglPriceadjustmentsheetService.SJgglPriceadjustmentsheetRemove(pd);
        return toAjax(integer);
    }

    /**
    * 价格调整通知 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jggl:jg:edit")
    @GetMapping("/sJgglPriceadjustmentsheetEdit/{id}")
    public String sjgglpriceadjustmentsheetView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sJgglPriceadjustmentsheetService.findSJgglPriceadjustmentsheetList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sjgglpriceadjustmentsheetPageEdit";
        }
        return prefix+ "/sjgglpriceadjustmentsheetEdit";
    }

    /**
    * 价格调整通知保存修改的数据
    */
    @RequiresPermissions("jggl:jg:edit")
    @Log(title = "价格调整通知修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sJgglPriceadjustmentsheetEdit")
    @ResponseBody
    public AjaxResult sjgglpriceadjustmentsheetEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sJgglPriceadjustmentsheetService.updateSJgglPriceadjustmentsheet(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sjgglpriceadjustmentsheet with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sjgglpriceadjustmentsheet with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
