package com.bzd.web.controller.jkgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.jkgl.SJkglCommissionrewardinfoService;

import java.util.List;

/**
*
* 合约提成发放失败明细 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "jkgl/sjkglcommissionrewardinfo")
public class SJkglCommissionrewardinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "jkgl";

    @Autowired
    private SJkglCommissionrewardinfoService sJkglCommissionrewardinfoService;

    /**
    * 合约提成发放失败明细 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglCommissionrewardinfoAdd")
    public String add() {
        return prefix + "/SJkglCommissionrewardinfoAdd";
    }

    /**
    * 合约提成发放失败明细 新增
    *
    * @return
    */
    @Log(title = "合约提成发放失败明细新增", businessType = BusinessType.INSERT)
    @PostMapping("/sJkglCommissionrewardinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sJkglCommissionrewardinfoService.addSJkglCommissionrewardinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 合约提成发放失败明细 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglCommissionrewardinfoView")
    public String sjkglcommissionrewardinfoListView() {
        return prefix + "/SJkglCommissionrewardinfoList";
    }

    /**
    * 合约提成发放失败明细 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:sJkglCommissionrewardinfoList")
    @PostMapping("/sJkglCommissionrewardinfoList")
    @ResponseBody
    public TableDataInfo sjkglcommissionrewardinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sJkglCommissionrewardinfoService.findSJkglCommissionrewardinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 合约提成发放失败明细 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:remove")
    @Log(title = "合约提成发放失败明细删除", businessType = BusinessType.DELETE)
    @PostMapping("/sJkglCommissionrewardinfoRemove")
    @ResponseBody
    public AjaxResult sjkglcommissionrewardinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sJkglCommissionrewardinfoService.SJkglCommissionrewardinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 合约提成发放失败明细 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:edit")
    @GetMapping("/sJkglCommissionrewardinfoEdit/{id}")
    public String sjkglcommissionrewardinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sJkglCommissionrewardinfoService.findSJkglCommissionrewardinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sjkglcommissionrewardinfoPageEdit";
        }
        return prefix+ "/sjkglcommissionrewardinfoEdit";
    }

    /**
    * 合约提成发放失败明细保存修改的数据
    */
    @RequiresPermissions("jkgl:jk:edit")
    @Log(title = "合约提成发放失败明细修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sJkglCommissionrewardinfoEdit")
    @ResponseBody
    public AjaxResult sjkglcommissionrewardinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sJkglCommissionrewardinfoService.updateSJkglCommissionrewardinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sjkglcommissionrewardinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sjkglcommissionrewardinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
