package com.bzd.web.controller.jkgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.jkgl.SJkglGyhyHyglContractinfoService;

import java.util.List;

/**
*
* 合约管理 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "jkgl/sjkglgyhyhyglcontractinfo")
public class SJkglGyhyHyglContractinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "jkgl";

    @Autowired
    private SJkglGyhyHyglContractinfoService sJkglGyhyHyglContractinfoService;

    /**
    * 合约管理 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglGyhyHyglContractinfoAdd")
    public String add() {
        return prefix + "/SJkglGyhyHyglContractinfoAdd";
    }

    /**
    * 合约管理 新增
    *
    * @return
    */
    @Log(title = "合约管理新增", businessType = BusinessType.INSERT)
    @PostMapping("/sJkglGyhyHyglContractinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sJkglGyhyHyglContractinfoService.addSJkglGyhyHyglContractinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 合约管理 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglGyhyHyglContractinfoView")
    public String sjkglgyhyhyglcontractinfoListView() {
        return prefix + "/SJkglGyhyHyglContractinfoList";
    }

    /**
    * 合约管理 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:sJkglGyhyHyglContractinfoList")
    @PostMapping("/sJkglGyhyHyglContractinfoList")
    @ResponseBody
    public TableDataInfo sjkglgyhyhyglcontractinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sJkglGyhyHyglContractinfoService.findSJkglGyhyHyglContractinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 合约管理 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:remove")
    @Log(title = "合约管理删除", businessType = BusinessType.DELETE)
    @PostMapping("/sJkglGyhyHyglContractinfoRemove")
    @ResponseBody
    public AjaxResult sjkglgyhyhyglcontractinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sJkglGyhyHyglContractinfoService.SJkglGyhyHyglContractinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 合约管理 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:edit")
    @GetMapping("/sJkglGyhyHyglContractinfoEdit/{id}")
    public String sjkglgyhyhyglcontractinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sJkglGyhyHyglContractinfoService.findSJkglGyhyHyglContractinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sjkglgyhyhyglcontractinfoPageEdit";
        }
        return prefix+ "/sjkglgyhyhyglcontractinfoEdit";
    }

    /**
    * 合约管理保存修改的数据
    */
    @RequiresPermissions("jkgl:jk:edit")
    @Log(title = "合约管理修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sJkglGyhyHyglContractinfoEdit")
    @ResponseBody
    public AjaxResult sjkglgyhyhyglcontractinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sJkglGyhyHyglContractinfoService.updateSJkglGyhyHyglContractinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sjkglgyhyhyglcontractinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sjkglgyhyhyglcontractinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
