package com.bzd.web.controller.jkgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.jkgl.SJkglMxbZdyFieldconfigService;

import java.util.List;

/**
*
* 自定义数据采集配置 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "jkgl/sjkglmxbzdyfieldconfig")
public class SJkglMxbZdyFieldconfigController extends BaseController {

    // 页面跳转前缀
    private String prefix = "jkgl";

    @Autowired
    private SJkglMxbZdyFieldconfigService sJkglMxbZdyFieldconfigService;

    /**
    * 自定义数据采集配置 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglMxbZdyFieldconfigAdd")
    public String add() {
        return prefix + "/SJkglMxbZdyFieldconfigAdd";
    }

    /**
    * 自定义数据采集配置 新增
    *
    * @return
    */
    @Log(title = "自定义数据采集配置新增", businessType = BusinessType.INSERT)
    @PostMapping("/sJkglMxbZdyFieldconfigAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sJkglMxbZdyFieldconfigService.addSJkglMxbZdyFieldconfig(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 自定义数据采集配置 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglMxbZdyFieldconfigView")
    public String sjkglmxbzdyfieldconfigListView() {
        return prefix + "/SJkglMxbZdyFieldconfigList";
    }

    /**
    * 自定义数据采集配置 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:sJkglMxbZdyFieldconfigList")
    @PostMapping("/sJkglMxbZdyFieldconfigList")
    @ResponseBody
    public TableDataInfo sjkglmxbzdyfieldconfigList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sJkglMxbZdyFieldconfigService.findSJkglMxbZdyFieldconfigList(pd);
        return getDataTable(pageData);
    }

    /**
    * 自定义数据采集配置 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:remove")
    @Log(title = "自定义数据采集配置删除", businessType = BusinessType.DELETE)
    @PostMapping("/sJkglMxbZdyFieldconfigRemove")
    @ResponseBody
    public AjaxResult sjkglmxbzdyfieldconfigRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sJkglMxbZdyFieldconfigService.SJkglMxbZdyFieldconfigRemove(pd);
        return toAjax(integer);
    }

    /**
    * 自定义数据采集配置 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:edit")
    @GetMapping("/sJkglMxbZdyFieldconfigEdit/{id}")
    public String sjkglmxbzdyfieldconfigView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sJkglMxbZdyFieldconfigService.findSJkglMxbZdyFieldconfigList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sjkglmxbzdyfieldconfigPageEdit";
        }
        return prefix+ "/sjkglmxbzdyfieldconfigEdit";
    }

    /**
    * 自定义数据采集配置保存修改的数据
    */
    @RequiresPermissions("jkgl:jk:edit")
    @Log(title = "自定义数据采集配置修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sJkglMxbZdyFieldconfigEdit")
    @ResponseBody
    public AjaxResult sjkglmxbzdyfieldconfigEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sJkglMxbZdyFieldconfigService.updateSJkglMxbZdyFieldconfig(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sjkglmxbzdyfieldconfig with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sjkglmxbzdyfieldconfig with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
