package com.bzd.web.controller.jkgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.jkgl.SJkglYpwxServiceprojectinfoService;

import java.util.List;

/**
*
* 药品维系服务 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "jkgl/sjkglypwxserviceprojectinfo")
public class SJkglYpwxServiceprojectinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "jkgl";

    @Autowired
    private SJkglYpwxServiceprojectinfoService sJkglYpwxServiceprojectinfoService;

    /**
    * 药品维系服务 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglYpwxServiceprojectinfoAdd")
    public String add() {
        return prefix + "/SJkglYpwxServiceprojectinfoAdd";
    }

    /**
    * 药品维系服务 新增
    *
    * @return
    */
    @Log(title = "药品维系服务新增", businessType = BusinessType.INSERT)
    @PostMapping("/sJkglYpwxServiceprojectinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sJkglYpwxServiceprojectinfoService.addSJkglYpwxServiceprojectinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 药品维系服务 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("jkgl:jk:view")
    @GetMapping("/sJkglYpwxServiceprojectinfoView")
    public String sjkglypwxserviceprojectinfoListView() {
        return prefix + "/SJkglYpwxServiceprojectinfoList";
    }

    /**
    * 药品维系服务 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:sJkglYpwxServiceprojectinfoList")
    @PostMapping("/sJkglYpwxServiceprojectinfoList")
    @ResponseBody
    public TableDataInfo sjkglypwxserviceprojectinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sJkglYpwxServiceprojectinfoService.findSJkglYpwxServiceprojectinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 药品维系服务 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:remove")
    @Log(title = "药品维系服务删除", businessType = BusinessType.DELETE)
    @PostMapping("/sJkglYpwxServiceprojectinfoRemove")
    @ResponseBody
    public AjaxResult sjkglypwxserviceprojectinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sJkglYpwxServiceprojectinfoService.SJkglYpwxServiceprojectinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 药品维系服务 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("jkgl:jk:edit")
    @GetMapping("/sJkglYpwxServiceprojectinfoEdit/{id}")
    public String sjkglypwxserviceprojectinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sJkglYpwxServiceprojectinfoService.findSJkglYpwxServiceprojectinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sjkglypwxserviceprojectinfoPageEdit";
        }
        return prefix+ "/sjkglypwxserviceprojectinfoEdit";
    }

    /**
    * 药品维系服务保存修改的数据
    */
    @RequiresPermissions("jkgl:jk:edit")
    @Log(title = "药品维系服务修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sJkglYpwxServiceprojectinfoEdit")
    @ResponseBody
    public AjaxResult sjkglypwxserviceprojectinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sJkglYpwxServiceprojectinfoService.updateSJkglYpwxServiceprojectinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sjkglypwxserviceprojectinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sjkglypwxserviceprojectinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
