package com.bzd.web.controller.spgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.spgl.SSpglMdjymlStoreproductinfoService;

import java.util.List;

/**
*
* 门店经营目录 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "spgl/sspglmdjymlstoreproductinfo")
public class SSpglMdjymlStoreproductinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "spgl";

    @Autowired
    private SSpglMdjymlStoreproductinfoService sSpglMdjymlStoreproductinfoService;

    /**
    * 门店经营目录 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglMdjymlStoreproductinfoAdd")
    public String add() {
        return prefix + "/SSpglMdjymlStoreproductinfoAdd";
    }

    /**
    * 门店经营目录 新增
    *
    * @return
    */
    @Log(title = "门店经营目录新增", businessType = BusinessType.INSERT)
    @PostMapping("/sSpglMdjymlStoreproductinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sSpglMdjymlStoreproductinfoService.addSSpglMdjymlStoreproductinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店经营目录 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglMdjymlStoreproductinfoView")
    public String sspglmdjymlstoreproductinfoListView() {
        return prefix + "/SSpglMdjymlStoreproductinfoList";
    }

    /**
    * 门店经营目录 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:sSpglMdjymlStoreproductinfoList")
    @PostMapping("/sSpglMdjymlStoreproductinfoList")
    @ResponseBody
    public TableDataInfo sspglmdjymlstoreproductinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sSpglMdjymlStoreproductinfoService.findSSpglMdjymlStoreproductinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店经营目录 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:remove")
    @Log(title = "门店经营目录删除", businessType = BusinessType.DELETE)
    @PostMapping("/sSpglMdjymlStoreproductinfoRemove")
    @ResponseBody
    public AjaxResult sspglmdjymlstoreproductinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sSpglMdjymlStoreproductinfoService.SSpglMdjymlStoreproductinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店经营目录 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:edit")
    @GetMapping("/sSpglMdjymlStoreproductinfoEdit/{id}")
    public String sspglmdjymlstoreproductinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sSpglMdjymlStoreproductinfoService.findSSpglMdjymlStoreproductinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sspglmdjymlstoreproductinfoPageEdit";
        }
        return prefix+ "/sspglmdjymlstoreproductinfoEdit";
    }

    /**
    * 门店经营目录保存修改的数据
    */
    @RequiresPermissions("spgl:sp:edit")
    @Log(title = "门店经营目录修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sSpglMdjymlStoreproductinfoEdit")
    @ResponseBody
    public AjaxResult sspglmdjymlstoreproductinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sSpglMdjymlStoreproductinfoService.updateSSpglMdjymlStoreproductinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sspglmdjymlstoreproductinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sspglmdjymlstoreproductinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
