package com.bzd.web.controller.spgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.spgl.SSpglProductattributesService;

import java.util.List;

/**
*
* 租赁商品管理 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "spgl/sspglproductattributes")
public class SSpglProductattributesController extends BaseController {

    // 页面跳转前缀
    private String prefix = "spgl";

    @Autowired
    private SSpglProductattributesService sSpglProductattributesService;

    /**
    * 租赁商品管理 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglProductattributesAdd")
    public String add() {
        return prefix + "/SSpglProductattributesAdd";
    }

    /**
    * 租赁商品管理 新增
    *
    * @return
    */
    @Log(title = "租赁商品管理新增", businessType = BusinessType.INSERT)
    @PostMapping("/sSpglProductattributesAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sSpglProductattributesService.addSSpglProductattributes(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 租赁商品管理 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglProductattributesView")
    public String sspglproductattributesListView() {
        return prefix + "/SSpglProductattributesList";
    }

    /**
    * 租赁商品管理 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:sSpglProductattributesList")
    @PostMapping("/sSpglProductattributesList")
    @ResponseBody
    public TableDataInfo sspglproductattributesList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sSpglProductattributesService.findSSpglProductattributesList(pd);
        return getDataTable(pageData);
    }

    /**
    * 租赁商品管理 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:remove")
    @Log(title = "租赁商品管理删除", businessType = BusinessType.DELETE)
    @PostMapping("/sSpglProductattributesRemove")
    @ResponseBody
    public AjaxResult sspglproductattributesRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sSpglProductattributesService.SSpglProductattributesRemove(pd);
        return toAjax(integer);
    }

    /**
    * 租赁商品管理 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:edit")
    @GetMapping("/sSpglProductattributesEdit/{id}")
    public String sspglproductattributesView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sSpglProductattributesService.findSSpglProductattributesList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sspglproductattributesPageEdit";
        }
        return prefix+ "/sspglproductattributesEdit";
    }

    /**
    * 租赁商品管理保存修改的数据
    */
    @RequiresPermissions("spgl:sp:edit")
    @Log(title = "租赁商品管理修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sSpglProductattributesEdit")
    @ResponseBody
    public AjaxResult sspglproductattributesEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sSpglProductattributesService.updateSSpglProductattributes(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sspglproductattributes with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sspglproductattributes with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
