package com.bzd.web.controller.spgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.spgl.SSpglProductdetailsService;

import java.util.List;

/**
*
* 连锁商品查询 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "spgl/sspglproductdetails")
public class SSpglProductdetailsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "spgl";

    @Autowired
    private SSpglProductdetailsService sSpglProductdetailsService;

    /**
    * 连锁商品查询 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglProductdetailsAdd")
    public String add() {
        return prefix + "/SSpglProductdetailsAdd";
    }

    /**
    * 连锁商品查询 新增
    *
    * @return
    */
    @Log(title = "连锁商品查询新增", businessType = BusinessType.INSERT)
    @PostMapping("/sSpglProductdetailsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sSpglProductdetailsService.addSSpglProductdetails(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 连锁商品查询 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("spgl:sp:view")
    @GetMapping("/sSpglProductdetailsView")
    public String sspglproductdetailsListView() {
        return prefix + "/SSpglProductdetailsList";
    }

    /**
    * 连锁商品查询 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:sSpglProductdetailsList")
    @PostMapping("/sSpglProductdetailsList")
    @ResponseBody
    public TableDataInfo sspglproductdetailsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sSpglProductdetailsService.findSSpglProductdetailsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 连锁商品查询 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:remove")
    @Log(title = "连锁商品查询删除", businessType = BusinessType.DELETE)
    @PostMapping("/sSpglProductdetailsRemove")
    @ResponseBody
    public AjaxResult sspglproductdetailsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sSpglProductdetailsService.SSpglProductdetailsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 连锁商品查询 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("spgl:sp:edit")
    @GetMapping("/sSpglProductdetailsEdit/{id}")
    public String sspglproductdetailsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sSpglProductdetailsService.findSSpglProductdetailsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sspglproductdetailsPageEdit";
        }
        return prefix+ "/sspglproductdetailsEdit";
    }

    /**
    * 连锁商品查询保存修改的数据
    */
    @RequiresPermissions("spgl:sp:edit")
    @Log(title = "连锁商品查询修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sSpglProductdetailsEdit")
    @ResponseBody
    public AjaxResult sspglproductdetailsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sSpglProductdetailsService.updateSSpglProductdetails(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sspglproductdetails with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sspglproductdetails with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
