package com.bzd.web.controller.xsgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xsgl.SXsglMdlsSalesinventoryinfoService;

import java.util.List;

/**
*
* 门店零售日报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "xsgl/sxsglmdlssalesinventoryinfo")
public class SXsglMdlsSalesinventoryinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xsgl";

    @Autowired
    private SXsglMdlsSalesinventoryinfoService sXsglMdlsSalesinventoryinfoService;

    /**
    * 门店零售日报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglMdlsSalesinventoryinfoAdd")
    public String add() {
        return prefix + "/SXsglMdlsSalesinventoryinfoAdd";
    }

    /**
    * 门店零售日报表 新增
    *
    * @return
    */
    @Log(title = "门店零售日报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXsglMdlsSalesinventoryinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXsglMdlsSalesinventoryinfoService.addSXsglMdlsSalesinventoryinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店零售日报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglMdlsSalesinventoryinfoView")
    public String sxsglmdlssalesinventoryinfoListView() {
        return prefix + "/SXsglMdlsSalesinventoryinfoList";
    }

    /**
    * 门店零售日报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:sXsglMdlsSalesinventoryinfoList")
    @PostMapping("/sXsglMdlsSalesinventoryinfoList")
    @ResponseBody
    public TableDataInfo sxsglmdlssalesinventoryinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXsglMdlsSalesinventoryinfoService.findSXsglMdlsSalesinventoryinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店零售日报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:remove")
    @Log(title = "门店零售日报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXsglMdlsSalesinventoryinfoRemove")
    @ResponseBody
    public AjaxResult sxsglmdlssalesinventoryinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXsglMdlsSalesinventoryinfoService.SXsglMdlsSalesinventoryinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店零售日报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:edit")
    @GetMapping("/sXsglMdlsSalesinventoryinfoEdit/{id}")
    public String sxsglmdlssalesinventoryinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXsglMdlsSalesinventoryinfoService.findSXsglMdlsSalesinventoryinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sxsglmdlssalesinventoryinfoPageEdit";
        }
        return prefix+ "/sxsglmdlssalesinventoryinfoEdit";
    }

    /**
    * 门店零售日报表保存修改的数据
    */
    @RequiresPermissions("xsgl:xs:edit")
    @Log(title = "门店零售日报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXsglMdlsSalesinventoryinfoEdit")
    @ResponseBody
    public AjaxResult sxsglmdlssalesinventoryinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXsglMdlsSalesinventoryinfoService.updateSXsglMdlsSalesinventoryinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxsglmdlssalesinventoryinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxsglmdlssalesinventoryinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
