package com.bzd.web.controller.xsgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xsgl.SXsglReturninfoService;

import java.util.List;

/**
*
* 销售退回 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "xsgl/sxsglreturninfo")
public class SXsglReturninfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xsgl";

    @Autowired
    private SXsglReturninfoService sXsglReturninfoService;

    /**
    * 销售退回 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglReturninfoAdd")
    public String add() {
        return prefix + "/SXsglReturninfoAdd";
    }

    /**
    * 销售退回 新增
    *
    * @return
    */
    @Log(title = "销售退回新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXsglReturninfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXsglReturninfoService.addSXsglReturninfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 销售退回 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglReturninfoView")
    public String sxsglreturninfoListView() {
        return prefix + "/SXsglReturninfoList";
    }

    /**
    * 销售退回 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:sXsglReturninfoList")
    @PostMapping("/sXsglReturninfoList")
    @ResponseBody
    public TableDataInfo sxsglreturninfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXsglReturninfoService.findSXsglReturninfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 销售退回 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:remove")
    @Log(title = "销售退回删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXsglReturninfoRemove")
    @ResponseBody
    public AjaxResult sxsglreturninfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXsglReturninfoService.SXsglReturninfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 销售退回 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:edit")
    @GetMapping("/sXsglReturninfoEdit/{id}")
    public String sxsglreturninfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXsglReturninfoService.findSXsglReturninfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sxsglreturninfoPageEdit";
        }
        return prefix+ "/sxsglreturninfoEdit";
    }

    /**
    * 销售退回保存修改的数据
    */
    @RequiresPermissions("xsgl:xs:edit")
    @Log(title = "销售退回修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXsglReturninfoEdit")
    @ResponseBody
    public AjaxResult sxsglreturninfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXsglReturninfoService.updateSXsglReturninfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxsglreturninfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxsglreturninfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
