package com.bzd.web.controller.xsgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xsgl.SXsglReturnproductinfoService;

import java.util.List;

/**
*
* 负号销售表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "xsgl/sxsglreturnproductinfo")
public class SXsglReturnproductinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xsgl";

    @Autowired
    private SXsglReturnproductinfoService sXsglReturnproductinfoService;

    /**
    * 负号销售表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglReturnproductinfoAdd")
    public String add() {
        return prefix + "/SXsglReturnproductinfoAdd";
    }

    /**
    * 负号销售表 新增
    *
    * @return
    */
    @Log(title = "负号销售表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXsglReturnproductinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXsglReturnproductinfoService.addSXsglReturnproductinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 负号销售表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xsgl:xs:view")
    @GetMapping("/sXsglReturnproductinfoView")
    public String sxsglreturnproductinfoListView() {
        return prefix + "/SXsglReturnproductinfoList";
    }

    /**
    * 负号销售表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:sXsglReturnproductinfoList")
    @PostMapping("/sXsglReturnproductinfoList")
    @ResponseBody
    public TableDataInfo sxsglreturnproductinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXsglReturnproductinfoService.findSXsglReturnproductinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 负号销售表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:remove")
    @Log(title = "负号销售表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXsglReturnproductinfoRemove")
    @ResponseBody
    public AjaxResult sxsglreturnproductinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXsglReturnproductinfoService.SXsglReturnproductinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 负号销售表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xsgl:xs:edit")
    @GetMapping("/sXsglReturnproductinfoEdit/{id}")
    public String sxsglreturnproductinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXsglReturnproductinfoService.findSXsglReturnproductinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sxsglreturnproductinfoPageEdit";
        }
        return prefix+ "/sxsglreturnproductinfoEdit";
    }

    /**
    * 负号销售表保存修改的数据
    */
    @RequiresPermissions("xsgl:xs:edit")
    @Log(title = "负号销售表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXsglReturnproductinfoEdit")
    @ResponseBody
    public AjaxResult sxsglreturnproductinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXsglReturnproductinfoService.updateSXsglReturnproductinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxsglreturnproductinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxsglreturnproductinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
