package com.bzd.web.controller.ybgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.ybgl.SYbglMedicaremanagementService;

import java.util.List;

/**
*
* 医保管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "ybgl/sybglmedicaremanagement")
public class SYbglMedicaremanagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "ybgl";

    @Autowired
    private SYbglMedicaremanagementService sYbglMedicaremanagementService;

    /**
    * 医保管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("ybgl:yb:view")
    @GetMapping("/sYbglMedicaremanagementAdd")
    public String add() {
        return prefix + "/SYbglMedicaremanagementAdd";
    }

    /**
    * 医保管理表 新增
    *
    * @return
    */
    @Log(title = "医保管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sYbglMedicaremanagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sYbglMedicaremanagementService.addSYbglMedicaremanagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 医保管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("ybgl:yb:view")
    @GetMapping("/sYbglMedicaremanagementView")
    public String sybglmedicaremanagementListView() {
        return prefix + "/SYbglMedicaremanagementList";
    }

    /**
    * 医保管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ybgl:yb:sYbglMedicaremanagementList")
    @PostMapping("/sYbglMedicaremanagementList")
    @ResponseBody
    public TableDataInfo sybglmedicaremanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sYbglMedicaremanagementService.findSYbglMedicaremanagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 医保管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ybgl:yb:remove")
    @Log(title = "医保管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sYbglMedicaremanagementRemove")
    @ResponseBody
    public AjaxResult sybglmedicaremanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sYbglMedicaremanagementService.SYbglMedicaremanagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 医保管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ybgl:yb:edit")
    @GetMapping("/sYbglMedicaremanagementEdit/{id}")
    public String sybglmedicaremanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sYbglMedicaremanagementService.findSYbglMedicaremanagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sybglmedicaremanagementPageEdit";
        }
        return prefix+ "/sybglmedicaremanagementEdit";
    }

    /**
    * 医保管理表保存修改的数据
    */
    @RequiresPermissions("ybgl:yb:edit")
    @Log(title = "医保管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sYbglMedicaremanagementEdit")
    @ResponseBody
    public AjaxResult sybglmedicaremanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sYbglMedicaremanagementService.updateSYbglMedicaremanagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sybglmedicaremanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sybglmedicaremanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
