package com.bzd.web.controller.ypdg;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.ypdg.SYpdgChineseDecoctionstService;

import java.util.List;

/**
*
* 中药代煎需求单表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "ypdg/sypdgchinesedecoctionst")
public class SYpdgChineseDecoctionstController extends BaseController {

    // 页面跳转前缀
    private String prefix = "ypdg";

    @Autowired
    private SYpdgChineseDecoctionstService sYpdgChineseDecoctionstService;

    /**
    * 中药代煎需求单表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("ypdg:yp:view")
    @GetMapping("/sYpdgChineseDecoctionstAdd")
    public String add() {
        return prefix + "/SYpdgChineseDecoctionstAdd";
    }

    /**
    * 中药代煎需求单表 新增
    *
    * @return
    */
    @Log(title = "中药代煎需求单表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sYpdgChineseDecoctionstAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sYpdgChineseDecoctionstService.addSYpdgChineseDecoctionst(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 中药代煎需求单表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("ypdg:yp:view")
    @GetMapping("/sYpdgChineseDecoctionstView")
    public String sypdgchinesedecoctionstListView() {
        return prefix + "/SYpdgChineseDecoctionstList";
    }

    /**
    * 中药代煎需求单表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ypdg:yp:sYpdgChineseDecoctionstList")
    @PostMapping("/sYpdgChineseDecoctionstList")
    @ResponseBody
    public TableDataInfo sypdgchinesedecoctionstList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sYpdgChineseDecoctionstService.findSYpdgChineseDecoctionstList(pd);
        return getDataTable(pageData);
    }

    /**
    * 中药代煎需求单表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ypdg:yp:remove")
    @Log(title = "中药代煎需求单表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sYpdgChineseDecoctionstRemove")
    @ResponseBody
    public AjaxResult sypdgchinesedecoctionstRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sYpdgChineseDecoctionstService.SYpdgChineseDecoctionstRemove(pd);
        return toAjax(integer);
    }

    /**
    * 中药代煎需求单表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ypdg:yp:edit")
    @GetMapping("/sYpdgChineseDecoctionstEdit/{id}")
    public String sypdgchinesedecoctionstView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sYpdgChineseDecoctionstService.findSYpdgChineseDecoctionstList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sypdgchinesedecoctionstPageEdit";
        }
        return prefix+ "/sypdgchinesedecoctionstEdit";
    }

    /**
    * 中药代煎需求单表保存修改的数据
    */
    @RequiresPermissions("ypdg:yp:edit")
    @Log(title = "中药代煎需求单表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sYpdgChineseDecoctionstEdit")
    @ResponseBody
    public AjaxResult sypdgchinesedecoctionstEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sYpdgChineseDecoctionstService.updateSYpdgChineseDecoctionst(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sypdgchinesedecoctionst with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sypdgchinesedecoctionst with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
