package com.bzd.web.controller.yxgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.yxgl.SYxglPromotioninfoService;

import java.util.List;

/**
*
* 促销列表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "yxgl/syxglpromotioninfo")
public class SYxglPromotioninfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "yxgl";

    @Autowired
    private SYxglPromotioninfoService sYxglPromotioninfoService;

    /**
    * 促销列表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("yxgl:yx:view")
    @GetMapping("/sYxglPromotioninfoAdd")
    public String add() {
        return prefix + "/SYxglPromotioninfoAdd";
    }

    /**
    * 促销列表 新增
    *
    * @return
    */
    @Log(title = "促销列表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sYxglPromotioninfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sYxglPromotioninfoService.addSYxglPromotioninfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 促销列表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("yxgl:yx:view")
    @GetMapping("/sYxglPromotioninfoView")
    public String syxglpromotioninfoListView() {
        return prefix + "/SYxglPromotioninfoList";
    }

    /**
    * 促销列表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:sYxglPromotioninfoList")
    @PostMapping("/sYxglPromotioninfoList")
    @ResponseBody
    public TableDataInfo syxglpromotioninfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sYxglPromotioninfoService.findSYxglPromotioninfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 促销列表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:remove")
    @Log(title = "促销列表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sYxglPromotioninfoRemove")
    @ResponseBody
    public AjaxResult syxglpromotioninfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sYxglPromotioninfoService.SYxglPromotioninfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 促销列表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:edit")
    @GetMapping("/sYxglPromotioninfoEdit/{id}")
    public String syxglpromotioninfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sYxglPromotioninfoService.findSYxglPromotioninfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/syxglpromotioninfoPageEdit";
        }
        return prefix+ "/syxglpromotioninfoEdit";
    }

    /**
    * 促销列表保存修改的数据
    */
    @RequiresPermissions("yxgl:yx:edit")
    @Log(title = "促销列表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sYxglPromotioninfoEdit")
    @ResponseBody
    public AjaxResult syxglpromotioninfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sYxglPromotioninfoService.updateSYxglPromotioninfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表syxglpromotioninfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表syxglpromotioninfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
