package com.bzd.web.controller.yxgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.yxgl.SYxglZhspCombinationproductService;

import java.util.List;

/**
*
* 组合商品信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "yxgl/syxglzhspcombinationproduct")
public class SYxglZhspCombinationproductController extends BaseController {

    // 页面跳转前缀
    private String prefix = "yxgl";

    @Autowired
    private SYxglZhspCombinationproductService sYxglZhspCombinationproductService;

    /**
    * 组合商品信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("yxgl:yx:view")
    @GetMapping("/sYxglZhspCombinationproductAdd")
    public String add() {
        return prefix + "/SYxglZhspCombinationproductAdd";
    }

    /**
    * 组合商品信息表 新增
    *
    * @return
    */
    @Log(title = "组合商品信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sYxglZhspCombinationproductAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sYxglZhspCombinationproductService.addSYxglZhspCombinationproduct(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 组合商品信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("yxgl:yx:view")
    @GetMapping("/sYxglZhspCombinationproductView")
    public String syxglzhspcombinationproductListView() {
        return prefix + "/SYxglZhspCombinationproductList";
    }

    /**
    * 组合商品信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:sYxglZhspCombinationproductList")
    @PostMapping("/sYxglZhspCombinationproductList")
    @ResponseBody
    public TableDataInfo syxglzhspcombinationproductList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sYxglZhspCombinationproductService.findSYxglZhspCombinationproductList(pd);
        return getDataTable(pageData);
    }

    /**
    * 组合商品信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:remove")
    @Log(title = "组合商品信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sYxglZhspCombinationproductRemove")
    @ResponseBody
    public AjaxResult syxglzhspcombinationproductRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sYxglZhspCombinationproductService.SYxglZhspCombinationproductRemove(pd);
        return toAjax(integer);
    }

    /**
    * 组合商品信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("yxgl:yx:edit")
    @GetMapping("/sYxglZhspCombinationproductEdit/{id}")
    public String syxglzhspcombinationproductView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sYxglZhspCombinationproductService.findSYxglZhspCombinationproductList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/syxglzhspcombinationproductPageEdit";
        }
        return prefix+ "/syxglzhspcombinationproductEdit";
    }

    /**
    * 组合商品信息表保存修改的数据
    */
    @RequiresPermissions("yxgl:yx:edit")
    @Log(title = "组合商品信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sYxglZhspCombinationproductEdit")
    @ResponseBody
    public AjaxResult syxglzhspcombinationproductEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sYxglZhspCombinationproductService.updateSYxglZhspCombinationproduct(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表syxglzhspcombinationproduct with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表syxglzhspcombinationproduct with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
